# Django WikiWikiWeb

Django WikiWikiWeb is a Python + Django Wiki app. It is heavily inspired by [the original Wiki](https://wiki.c2.com/?) built by Ward Cunningham, whilst not quite being a [WikiClone](https://wiki.c2.com/?WikiWikiClones). It contains a few extra, modern features, integrates with the Django admin and auth systems, and will not be recreating the [controversial](https://news.ycombinator.com/item?id=8983158) newer JavaScript/single-page interface. 

## Requirements

 - [Django 5](https://docs.djangoproject.com/en/5.0/topics/install/) - ```pip install Django```
 - [django-markdownify](https://django-markdownify.readthedocs.io/en/latest/index.html) - ```pip install django-markdownify```
 - [django-simple-history](https://django-simple-history.readthedocs.io/en/latest/) - ```pip install django-simple-history```
 - [django-bootstrap5](https://pypi.org/project/django-bootstrap5/) - ```pip install django-bootstrap5```

Plus whichever database backend you prefer, for example:

- [mysqlclient](https://pypi.org/project/mysqlclient/) - ```pip install mysqlclient```

## Documentation

The full documentation will be at https://django-wikiwikiweb.readthedocs.io/

